@@ -3,6 +3,7 @@
 //! in order to communicate with vehicle ECUs
 
 pub mod passthru;
+pub mod dpdu;
 
 #[cfg(unix)]
 pub mod socketcan;
@@ -33,6 +34,12 @@ pub trait Hardware {
     /// Should the adapter not support this feature, [std::option::Option::None] is returned
     fn read_battery_voltage(&mut self) -> Option<f32>;
 
+    /// Tries to read battery voltage from the igntion pin on the OBD2 port. A reading
+    /// would indicate ignition is on in the vehicle.
+    /// This is mainly used by diagnostic adapters, and is purely optional
+    /// Should the adapter not support this feature, [std::option::Option::None] is returned
+    fn read_ignition_voltage(&mut self) -> Option<f32>;
+
     /// Returns a list of hardware capabilities
     fn get_capabilities(&self) -> &HardwareCapabilities;
 }
