@@ -377,6 +377,21 @@ impl super::Hardware for PassthruDevice {
         }
     }
 
+    fn read_ignition_voltage(&mut self) -> Option<f32> {
+        let mut output: u32 = 0;
+        match self.safe_passthru_op(|idx, drv: PassthruDrv| {
+            drv.ioctl(
+                idx,
+                IoctlID::READ_PROG_VOLTAGE,
+                std::ptr::null_mut(),
+                (&mut output) as *mut _ as *mut c_void,
+            )
+        }) {
+            Ok(_) => Some(output as f32 / 1000.0),
+            Err(_) => None,
+        }
+    }
+
     fn get_capabilities(&self) -> &super::HardwareCapabilities {
         &self.info.capabilities
     }
