@@ -12,12 +12,12 @@ use super::{KWP2000Command, Kwp2000DiagnosticServer};
 ///
 /// | DTCRange | Support by ECUs |
 /// |--|--|
-/// |[DTCRange::AllPowertrain]|Optional|
-/// |[DTCRange::AllChassis]|Optional|
-/// |[DTCRange::AllBody]|Optional|
-/// |[DTCRange::AllNetwork]|Optional|
-/// |[DTCRange::AllDTCs]|Mandatory|
-/// |[DTCRange::SingleDTC]|Optional|
+/// |[ClearDTCRange::AllPowertrain]|Optional|
+/// |[ClearDTCRange::AllChassis]|Optional|
+/// |[ClearDTCRange::AllBody]|Optional|
+/// |[ClearDTCRange::AllNetwork]|Optional|
+/// |[ClearDTCRange::AllDTCs]|Mandatory|
+/// |[ClearDTCRange::SingleDTC]|Optional|
 pub enum ClearDTCRange {
     /// All powertrain related DTCs
     AllPowertrain,
@@ -61,7 +61,7 @@ pub fn clear_dtc(
     server
         .execute_command_with_response(
             KWP2000Command::ClearDiagnosticInformation,
-            &[(dtc_range_num << 8) as u8, dtc_range_num as u8],
+            &[(dtc_range_num >> 8) as u8, dtc_range_num as u8],
         )
         .map(|_| ())
 }
